/*******************************************************************************
* FILE NAME: auto_routines.h
*
*	Version 3.13	last updated 2/2/06
*
* DESCRIPTION:
*  This file contains several sample autonomous techniques as a
*  progressive development from prinitive to more sophisticated.
*******************************************************************************/

#ifndef __auto_routines_h_
#define __auto_routines_h_

#ifdef VARIABLE_DECLARE
   char Shooter_Status, Drive_Status, Joint_Status;
   int lastDriveCmd, lastShooterCmd, lastJointCmd;
   unsigned char DriveCmd, ShooterCmd, JointCmd; // Current cmd # in script
   unsigned char cmdNum,lastcmdNum;
   unsigned char holdflag=0;
   unsigned char start_position = 0;
   unsigned char saved_p1_wheel=127;  //DEBUG
#else
  extern char Shooter_Status, Drive_Status, Joint_Status;
  extern int lastDriveCmd, lastShooterCmd, lastJointCmd;
  extern unsigned char DriveCmd, ShooterCmd, JointCmd; // Current cmd # in script
  extern unsigned char cmdNum,lastcmdNum;
  extern unsigned char holdflag;
  extern unsigned char start_position;
  extern unsigned char saved_p1_wheel;  //DEBUG
#endif

/**** Script Commands ****/
  #define ENDCMD        0   /* Must always be the last command */

  /* Driving commands */
  #define DFWD          1   /* Drive Forward for a time */
  #define DBCK          2   /* Drive Backward for a time */
  #define DSPIN         3   /* Spin in place for a time */
  #define DISTFWD       4   /* Drive forward a distance */
  #define DISTBCK       5   /* Drive backward a distance */
  #define DSTOP         7   /* Stop all engines */
  #define GTRN          8   /* Gyro controlled turn */
  /* Add new drive cmds here */
  #define GTRNS         19   /* Gyro controlled turn stops at overshoot*/ // Keep as last Drive command

  /* Joint commands - requires both shooter and drive queues to complete */
  #define DELAY   	    20  /* Sit still for a time */
  #define SYNC          21  /* Wait for both shooter and drive cmds to complete before proceeding */
 /* Add new joint cmds here */

  /* Shooter commands */
  #define SHOOTEROFF    31   /* Shooter Startup */  // Keep as first Shooter command
  #define SHOOTERON	    32   /* Shooter Startup */
  #define SETPAN        33   /* Set a pan position */
  #define FIRE          34   /* Fire a Poof ball */
  #define PANTRACK      35   /* Pan to track target with camera */
  #define TLOCK         36   /* Do we have target lock with camera? */
  #define CONVEYON      37   // Turn on the conveyor/harvester
  #define CONVEYOFF     38   // Turn on the conveyor/harvester
  /* Add new shooter cmds here */

  /******** End Script Commands *********/

  /* command array indexes - cmd parameters depend on the cmd */
  #define CMD           0

  #define CMDTIME       1
  #define CMDDIST       1
  #define CMDDISTRIGHT  1
  #define CMDGHEADING   1
  #define CMDIRHEADING  1
  #define CMDSETTING    1

  #define CMDSPEED      2
  #define CMDDISTLEFT   2

  #define CMDDIRECTION  3
  #define CMDFASTER     3

  /*************************/

/* Direction, speed */
#define CW               1  // Clockwise
#define CCW              0  // Counter clockwise
#define NONE             0
#define NEUTRAL          0
#define FULLSPEED      127 
#define PIDSPEED       100  // Max to allow PID control leaway
#define HALFSPEED       64
#define QTRSPEED        32
#define SLOWDOWN        500 // Encoder distance at which to start slowing down (500=21 in.)
#define SLOWDOWNGYRO    10  // Gyro degrees from target at which to start slowing down
#define MINTURNSPEED    70  // Minimum speed in autonomous turn (was 50)
#define MINSPEED        30  // Minimum speed driving straight (25 is absolute min)
#define MINWINDOW       20   //Target encoder window considered success (5 is too small,20 is okay)

#define MAXTIME			65535

#define DISTCALLS	   128			//number of times shaft encoder called per circ 

/* Command queue status */
#define COMPLETE     0
#define INCOMPLETE   1
#define JOINT        2

#define STARTLEFT   1
#define STARTCENTER 2
#define STARTRIGHT  3

/* This is the autonomous mode switched to.... this is always called in autonomous... */

void Switch_Auto(rom const int *);

/*Driving functions */
void Auto_Hold_Position(void);
void Drive_Forward_Time(int,int);
void Drive_Backward_Time(int,int);
void Drive_Spin_In_Place_Time(int, int, int);
void Drive_Stop(void);
void Gyro_Turn(signed int);
void Gyro_Turn_Sloppy(signed int);
void Drive_Forward_Time_Gyro(int, int);
void Drive_Forward_Dist(int, int);


/* Shooter functions */
void Shooter_On(void);
void Shooter_Off(void);
void Fire_Poof(void);
void Set_Pan_Position(int);
void Pan_Track(void);
void Target_Lock(void);

void Auto_Fire(void);

/* Miscellaneous */
void Delay(int);
void Sync_Drive_Shooter(int);
void Conveyor_On(void);
void Conveyor_Off(void);

#endif
