/*******************************************************************************
* FILE NAME: auto_scripts.c
*
* DESCRIPTION:
*  These are all the autonomous command scripts
*  The auto script is selected via the 10 position auto mode switch on the robot.
*
* USAGE:
*  Modify scripts as required
*  Cut & Paste command templates located at the bottom of this file
*
*  Drive commands must be intermixed with Shooter commands carefully.
*  Two of either type in a row will block further command processing
*  until one of them has cleared the queue.
*
* Avoid running motors at full speed, so PID has room to adjust
*
*******************************************************************************/
#define AUTO_HEIGHT		30  // Maximum number of script commands
#define AUTO_WIDTH		4   // Maximum number of command parameters

//***********************
//   Auto 0  - Do nothing
//   Auto 1  - Take center field, square-up with goal, drive in close, and shoot
//   Auto 2  - Drive straight at goal while shooting (HALF speed)
//   Auto 3  - Drive straight to block
//   Auto 4  - Similar to Auto 1 but faster and shorter
//   Auto 5  - Same as 1, but starts as 2 (pretends to point at goal)
//   Auto 6  - straight at goal while shooting (Full SPEED)
//   Auto 7  - straight at goal while shooting FAST but shorter
//   Auto 8  - straight at goal while shooting DELAYED
//   Auto 9  - Tests
//***********************

/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_0[AUTO_HEIGHT*AUTO_WIDTH] = 
  {  // Do nothing, sit still, don't move, try not to breathe
   ENDCMD, NONE,  NONE,       NONE     //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_0[AUTO_HEIGHT*AUTO_WIDTH] = 
  {  // Do nothing, sit still, don't move, try not to breathe
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   FIRE,          0,         0,        0,  // Fire a poof ball
   FIRE,          0,         0,        0,  // Fire a poof ball
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   FIRE,          0,         0,        0,  // Fire a poof ball
   FIRE,          0,         0,        0,  // Fire a poof ball
   FIRE,          0,         0,        0,  // Fire a poof ball
   FIRE,          0,         0,        0,  // Fire a poof ball
   FIRE,          0,         0,        0,  // Fire a poof ball
   FIRE,          0,         0,        0,  // Fire a poof ball
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   ENDCMD, NONE,  NONE,       NONE     //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_0[AUTO_HEIGHT*AUTO_WIDTH] = 
  {  // Do nothing, sit still, don't move, try not to breathe
   ENDCMD, NONE,  NONE,       NONE     //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_1[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // Take center field, square-up with goal, drive in close, and shoot
   DFWD,         13,     HALFSPEED,    0,  // Turn to a heading (degrees)
   GTRNS,        88,         0,        0,  // was 85 in finals 2 at UTC
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,          12,     HALFSPEED,    0,  // Get closer to the goal
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
   ENDCMD, NONE,  NONE,       NONE     //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_1[AUTO_HEIGHT*AUTO_WIDTH] = 
  {  // Take center field, square-up with goal, drive in close, and shoot
   DFWD,         13,     HALFSPEED,    0,  // Turn to a heading (degrees)
   GTRNS,        88,         0,        0,  // was 85 in finals 2 at UTC
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,         15,     HALFSPEED,    0,  // Get closer to the goal
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_1[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // Take center field, square-up with goal, drive in close, and shoot
   DFWD,         12,     HALFSPEED,    0,  // Turn to a heading (degrees)
   GTRNS,        88,         0,        0,  // was 85 in finals 2 at UTC
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,          9,     HALFSPEED,    0,  // Get closer to the goal
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
   ENDCMD, NONE,  NONE,       NONE     //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_2[AUTO_HEIGHT*AUTO_WIDTH] = 
  {  // Drive straight at goal and shoot
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,         13,     HALFSPEED,    0,  // Drive forward (time)
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_2[AUTO_HEIGHT*AUTO_WIDTH] = 
  {  // Drive straight at goal and shoot
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,         17,     HALFSPEED,    0,  // Turn to a heading (degrees)
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_2[AUTO_HEIGHT*AUTO_WIDTH] = 
  {  // Drive straight at goal and shoot
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,         9,     HALFSPEED,    0,  // Turn to a heading (degrees)
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_3[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // Drive straight across
   DFWD,    10, FULLSPEED,  0,
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_3[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // Drive straight across
   DFWD,    10, FULLSPEED,  0,
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_3[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // Drive straight across
   DFWD,    10, FULLSPEED,  0,
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_4[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // Pull out straight across, square-up with goal, drive in close, and shoot
   DFWD,         13,     HALFSPEED,    0,  // Turn to a heading (degrees)
   GTRNS,        88,         0,        0,  // was 85 in finals 2 at UTC
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,         12,     HALFSPEED,    0,  // Get closer to the goal
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_4[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // Pull out straight across, square-up with goal, drive in close, and shoot
   DFWD,         13,     HALFSPEED,    0,  // Turn to a heading (degrees)
   GTRNS,        88,         0,        0,  // was 85 in finals 2 at UTC
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,         15,     HALFSPEED,    0,  // Get closer to the goal
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_4[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // Pull out straight across, square-up with goal, drive in close, and shoot
   DFWD,         13,     HALFSPEED,    0,  // Turn to a heading (degrees)
   GTRNS,        88,         0,        0,  // was 85 in finals 2 at UTC
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,          9,     HALFSPEED,    0,  // Get closer to the goal
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_5[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // Start pointing at goal, Take center field, square-up with goal, drive in close, and shoot
   GTRNS,         0,         0,        0,  // Turn away from goal
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,         13,     HALFSPEED,    0,  // Turn to a heading (degrees)
   GTRNS,        88,         0,        0,  // Turn back to goal
   DFWD,         12,     HALFSPEED,    0,  // Get closer to the goal
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_5[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // Start pointing at goal, Take center field, square-up with goal, drive in close, and shoot
   GTRNS,         0,         0,        0,  // Turn away from goal
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,         13,     HALFSPEED,    0,  // Turn to a heading (degrees)
   GTRNS,        88,         0,        0,  // Turn back to goal
   DFWD,         15,     HALFSPEED,    0,  // Get closer to the goal
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_5[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // Start pointing at goal, Take center field, square-up with goal, drive in close, and shoot
   GTRNS,         0,         0,        0,  // Turn away from goal
   DFWD,         13,     HALFSPEED,    0,  // Turn to a heading (degrees)
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   GTRNS,        88,         0,        0,  // Turn back to goal
   DFWD,          9,     HALFSPEED,    0,  // Get closer to the goal
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_6[AUTO_HEIGHT*AUTO_WIDTH] = 
  { //straight at goal while shooting (Full SPEED)
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,          6,     FULLSPEED,    0,  // Drive forward (time)
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
  ENDCMD, NONE,  NONE,       NONE    //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_6[AUTO_HEIGHT*AUTO_WIDTH] = 
  { //straight at goal while shooting (Full SPEED)
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,         7,     FULLSPEED,    0,  // Turn to a heading (degrees)
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
  ENDCMD, NONE,  NONE,       NONE    //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_6[AUTO_HEIGHT*AUTO_WIDTH] = 
  { //straight at goal while shooting (Full SPEED)
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,          4,     FULLSPEED,    0,  // Turn to a heading (degrees)
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
  ENDCMD, NONE,  NONE,       NONE    //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_7[AUTO_HEIGHT*AUTO_WIDTH] = 
  { // straight at goal while shooting FAST but shorter
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,          3,     FULLSPEED,    0,  // Drive forward (time)
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_7[AUTO_HEIGHT*AUTO_WIDTH] = 
  {// straight at goal while shooting FAST but shorter
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,         4,     FULLSPEED,    0,  // Turn to a heading (degrees)
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_7[AUTO_HEIGHT*AUTO_WIDTH] = 
  {// straight at goal while shooting FAST but shorter
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DFWD,          2,     FULLSPEED,    0,  // Turn to a heading (degrees)
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
   ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_8[AUTO_HEIGHT*AUTO_WIDTH] = 
  {//straight at goal while shooting DELAYED
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DELAY,        8,         0,        0,  // Sit still (time)
   DFWD,         13,     HALFSPEED,    0,  // Drive forward (time)
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_8[AUTO_HEIGHT*AUTO_WIDTH] = 
  { //straight at goal while shooting DELAYED
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DELAY,        8,         0,        0,  // Sit still (time)
   DFWD,         17,     HALFSPEED,    0,  // Turn to a heading (degrees)
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_8[AUTO_HEIGHT*AUTO_WIDTH] = 
  {//straight at goal while shooting DELAYED
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   DELAY,        8,         0,        0,  // Sit still (time)
   DFWD,         9,     HALFSPEED,    0,  // Turn to a heading (degrees)
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_CENTER_9[AUTO_HEIGHT*AUTO_WIDTH] = 
  {
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   DFWD,          20,     QTRSPEED,     0,  // Turn to a heading (degrees)
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_LEFT_9[AUTO_HEIGHT*AUTO_WIDTH] = 
  {
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
rom const	int  AUTO_RIGHT_9[AUTO_HEIGHT*AUTO_WIDTH] = 
  {
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   FIRE,          0,         0,        0,  // Fire a poof ball
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   PANTRACK,      0,         0,        0,  // Track target with camera
   FIRE,          0,         0,        0,  // Fire a poof ball
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
  ENDCMD, NONE,  NONE,       NONE  //MUST be the last command
  };
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/
/*-----------------------------------------------------------------------------*/

  /******** End autonomous commands ********/
  /*****************************************/
  /*****************************************/

/*******************************************************************************
* TIME is in tenths of seconds
* SPEED is 0-127
* DISTANCE is in inches
*
   ENDCMD,      0,           0,     0,   // ALWAYS the last command in a script
*
* Driving :
*(timed) - 
   DFWD,     TIME,   FULLSPEED,     0,  // Drive Forward (time,speed)
   DSPIN,    TIME,   FULLSPEED,    CW,  // Spin (time, speed, CW or CCW)
   DBCK,     TIME,   FULLSPEED,     0,  // Drive Backward (time,speed)
   DSTOP,    0,          0,         0,  // 
   DISTFWD,  DIST,   FULLSPEED,     0,  // Drive x inches at y speed
* (sensor based)
   GTRN,  GYROHEADING,   0,         0,  // Turn to a heading (degrees)
   GTRNS, GYROHEADING,   0,         0,  // Turn to a heading (degrees) stop on overshoot
* (other)
*
* SHOOTER:
   SHOOTERON,     0,         0,        0,  // Power up the shooter
   SHOOTEROFF,    0,         0,        0,  // Power down the shooter
   FIRE,          0,         0,        0,  // Fire a poof ball
   SETPAN,        SETTING,   0,        0,  // Set a pan position
   PANTRACK,      0,         0,        0,  // Track target with camera
   TLOCK,         0,         0,        0,  // Do we have a target lock? (never releases if not)
   CONVEYON,      0,         0,        0,  // Power up the conveyor
   CONVEYOFF,     0,         0,        0,  // Power down the conveyor
*
* JOINT:
   DELAY,    TIME,        0,        0,  // Sit still (time)
*
*
* BROKEN COMMANDS:
*
* DIAGNOSTIC COMMANDS:
*
* PARAMETERS:
*  TIME: 1-100 tenths of seconds
*  Distance: inches
*  Direction: CW or CCW
*  Speed: 1-127
*  Gyro heading: -360 to 360 & beyond, 0 is the original robot heading straight forward/backward
*  DSPIN times:  2sec=260 degrees,  .8sec = 90 degrees
*  DFWD times: 
*******************************************************************************/
