////////////////////////////////////////////////////
//	Gyro Interface Code  // 2/11/06 // Matt Krass //
////////////////////////////////////////////////////
//												  //
//		Notes: Be EXPLICIT!						  //
//             But keep it clean!!!               //
////////////////////////////////////////////////////

#include <stdio.h>

#include "ifi_utilities.h"
#include "ifi_aliases.h"
#include "ifi_default.h"
#include "user_routines.h"
#define VARIABLE_DECLARE
	#include "gyro.h"
#undef VARIABLE_DECLARE

#define GYRO_READY 30
#define GYRO_SETTLE 5
#define SAMPLE_RATE 40/250

void Gyro()
{
	static signed int GyroPrev = 0;
	static signed int GyroSample = 0;
	static unsigned long LastClocksec = 0;
	static unsigned long LastClockms = 0;
	static unsigned int GyroStartup = 0;
	static long GyroNeutral = 0;
	
	if(GyroTicks > 0)
	{
		INTCONbits.GIEL = 0; // Disable low priority interrupts
		GyroTicks--; // Decrement without interrupts
		INTCONbits.GIEL = 1; // Re-enable low priority interrupts

		if(GyroStartup == GYRO_READY)
		{
			// OLD: GyroSample = Get_Analog_Value(rc_ana_in02) - GyroNeutral;
			GyroSample = (int)Get_Analog_Value(GYROINPUT) - GyroNeutral;
//printf("Analog 1=%d\r",Get_Analog_Value(GYROINPUT));
			GyroSample = GyroSample * SAMPLE_RATE;
			//printf("GyroSample, %d, GyroNeutral, %d\r", GyroSample, GyroNeutral);
			RawHeading += (GyroSample + GyroPrev) / 2;
			//RawHeading += GyroSample;
			//printf("RawHeading, %ld\r", RawHeading);
			//printf("GyroSample, %d, GyroPrev, %d, RawHeading, %ld, GyroNeutral=%d\r",GyroSample,GyroPrev,RawHeading,GyroNeutral);
			GyroPrev = GyroSample;
			//GyroPrev = 0;
		}
		else
		{
			GyroStartup++;
			if(GyroStartup > GYRO_SETTLE)
			{
				GyroNeutral += Get_Analog_Value(GYROINPUT)<<6;
				//printf("GyroNeutral=%d\r", GyroNeutral);
				if(GyroStartup == GYRO_READY)
				{
					GyroNeutral /= (GYRO_READY - GYRO_SETTLE);
					GyroNeutral = (GyroNeutral+32)>>6;
					
					GyroPrev = 0;
					RawHeading = 0;
				}
			}
		}
	}
}


// Clockwise = Positive
// Counter-Clockwise = Negative
#define RTKP	2 // was 1
#define RTKI	 5/10 // was 0 
#define RTKD    0 // was 0
#define MaxCumErr	300
#define MinCumErr	-300
#define GyroSign	-1

signed int GyroTurnRaw(signed int TargetRawHeading)
{
	signed int p_out = 0;
	signed int i_out = 0;
	signed int d_out = 0;
	signed int pwm_out = 0;
	
	signed int delta = 0;
	static signed long PrevRawHeading = 0;

	error = ((signed long)RawHeading - TargetRawHeading) * GyroSign;
	delta = RawHeading - PrevRawHeading;
	p_out = (error * (RTKP));
	i_out = ((long)cum_error * RTKI);
	d_out = (delta * RTKD);
	pwm_out  = p_out + i_out + d_out;

	if((error >= 1 || error <= -1) && disabled_mode == 0)
		cum_error += error;
	else
		pwm_out = cum_error = 0;
	if(cum_error > MaxCumErr)
		cum_error = MaxCumErr;
	if(cum_error < MinCumErr)
		cum_error = MinCumErr;
	
	if(pwm_out >  127)
		pwm_out =  127;
	if(pwm_out < -127)
		pwm_out = -127;

	PrevRawHeading = RawHeading;
	return pwm_out;
}

signed int GyroDrive(signed int speed)
{
	signed int turn_pwm;
	static signed long TargetRawHeading;
	signed int output;
	static char init;
	printf("Init, %d\r",init);
	if(!init)
	{
		TargetRawHeading = RawHeading;
		init++;
	}
	else
	{
		turn_pwm = GyroTurnRaw(TargetRawHeading);
		if(speed > 100)
			speed = 100;
		if(speed < -100)
			speed = -100;

		output = speed + turn_pwm;
		
        if(output > 127)
			output = 127;
		if(output < -127)
			output = -127;
	}
	
	return output;
}
