/*******************************************************************************
* FILE NAME: main.c
*
* DESCRIPTION:
*  This file contains the main program loop.
*
* USAGE:
*  You should not need to modify this file.
*  Note the different loop speed for the two routines:
*     Process_Data_From_Master_uP
*     Process_Data_From_Local_IO
*******************************************************************************/

#include "ifi_aliases.h"
#include "ifi_default.h"
#include "ifi_utilities.h"
#include "user_routines.h"
#include "utilities.h"
#include "camera.h"
#include "gyro.h"
#include "stdio.h"
#include "auto_routines.h"

tx_data_record txdata;          /* DO NOT CHANGE! */
rx_data_record rxdata;          /* DO NOT CHANGE! */
packed_struct statusflag;       /* DO NOT CHANGE! */

/*******************************************************************************
* FUNCTION NAME: main
* PURPOSE:       Main program function.
* CALLED FROM:   ifi_startup.c
* ARGUMENTS:     none
* RETURNS:       void
* DO NOT DELETE THIS FUNCTION 
*******************************************************************************/
#define STARTDELAY 38    // ~ One second at 26.2ms/loop or use the system clock

void main (void)
{
  /* Give the RC & OI systems time to yawn, stretch, have a little coffee - generally wake-up */
  /* Note sensors powered directly from 12v supply (eg Banners) may not initialize at the same time */
  static char warmUp= STARTDELAY;  // ~ One half second at 26.2ms/loop

#ifdef UNCHANGEABLE_DEFINITION_AREA
  IFI_Initialization ();        /* DO NOT CHANGE! */
#endif

  User_Initialization();        /* You edit this in user_routines.c */
//  Restart_Camera();
  AutoFirstTime=FALSE;    // Reinitialize autonomous whenever the robot is disabled not when it resets

  statusflag.NEW_SPI_DATA = 0;  /* DO NOT CHANGE! */ 

  while (1)   /* This loop will repeat indefinitely. */
  {
#ifdef _SIMULATOR
    statusflag.NEW_SPI_DATA = 1;
#endif

    if (statusflag.NEW_SPI_DATA)      /* 26.2ms loop area */
    {                                 /* I'm slow!  I only execute every 26.2ms because */
                                      /* that's how fast the Master uP gives me data. */
     Getdata(&rxdata);   /* Get fresh data from the master microprocessor. */
     if (warmUp > 0) // digital & OI inputs are suspect @ startup. Give them time to warm up
     {
        warmUp--;
     }
     else
     {
   	  ConvertInputs();  // Convert input joystick values to zero neutral
      Process_Data_From_Master_uP();  /* You edit this in user_routines.c */

      COMPRESSOR = !PRESSURE;  /* Power pump only if pressure switch is off. */    

      if(p1_wheel != 127) saved_p1_wheel = p1_wheel;
//      printf("p1_wheel=%d, saved_p1_wheel=%d\r", p1_wheel, saved_p1_wheel);

      if (disabled_mode)  // Robot is disabled
      {
        notmoving = FALSE;  // Flag if the robot is ready to hold position
        AutoFirstTime=TRUE; // Reset autonomous whenever the robot is disabled
        DriverFirstTime=TRUE; // Reset driver whenever the robot is disabled
        Gyro();  // Initialize gyro
      }
      else if (autonomous_mode)  // Robot is in autonomous
      {
        notmoving = FALSE;
        User_Autonomous_Code();
      }
      else  // Robot is in normal human driver mode
      {
        Driver_Routine();
        AutoFirstTime=TRUE; // Reset autonomous whenever the driver takes over
      }
    	ConvertOutputs(); /* Convert pwms to int and the range 0 to 254 */
     }

      Update_OI();  // Update the OI LEDs and dashboard display
      Putdata(&txdata);             /* DO NOT CHANGE! */
    }

    if (warmUp == 0) // digital & OI inputs are suspect @ startup. Give them time to warm up
      Process_Data_From_Local_IO();  // I'm fast!  I execute during every loop.

  } /* while (1) */
}  /* END of Main */


/******************************************************************************/
/******************************************************************************/
/******************************************************************************/
