/*******************************************************************************
* FILE NAME: utilities.c
*
* DESCRIPTION:
*  Miscellaneous useful routines  
*
*******************************************************************************/
#include <portb.h>

#include "ifi_aliases.h"
#include "ifi_default.h"
#include "user_routines.h"

#define VARIABLE_DECLARE  /* causes certain global variables to be declared only once */
  #include "utilities.h"
#undef VARIABLE_DECLARE

/*******************************************************************************
* FUNCTION NAME: ConvertInputs
* PURPOSE:       Converts pwm 0 - 254 range to -127 to 127
 *******************************************************************************/
void ConvertInputs(void)
{
	ip1_y = (signed int) p1_y - 127;
	ip2_y = (signed int) p2_y - 127;
	ip3_y = (signed int) p3_y - 127;
	ip4_y = (signed int) p4_y - 127;
	ip1_x = (signed int) p1_x - 127;
	ip2_x = (signed int) p2_x - 127;
	ip3_x = (signed int) p3_x - 127;
	ip4_x = (signed int) p4_x - 127;
    ip1_wheel = (signed int) p1_wheel - 127;
    ip2_wheel = (signed int) p2_wheel - 127;   
    ip3_wheel = (signed int) p3_wheel - 127;   
    ip4_wheel = (signed int) p4_wheel - 127; 
    ip1_aux = (signed int) p1_aux - 127;
    ip2_aux = (signed int) p2_aux - 127;   
    ip3_aux = (signed int) p3_aux - 127;   
    ip4_aux = (signed int) p4_aux - 127; 
}

/*******************************************************************************
* FUNCTION NAME: ConvertOutputs
* PURPOSE:       Converts pwm -127 to 127 range to 0 - 254
*******************************************************************************/
void ConvertOutputs(void)
{
  if (ipwm01 < -127) ipwm01=-127;
  if (ipwm02 < -127) ipwm02=-127;
  if (ipwm03 < -127) ipwm03=-127;
  if (ipwm04 < -127) ipwm04=-127;
  if (ipwm05 < -127) ipwm05=-127;
  if (ipwm06 < -127) ipwm06=-127;
  if (ipwm07 < -127) ipwm07=-127;
  if (ipwm08 < -127) ipwm08=-127;
  if (ipwm09 < -127) ipwm09=-127;
  if (ipwm10 < -127) ipwm10=-127;
  if (ipwm11 < -127) ipwm11=-127;
  if (ipwm12 < -127) ipwm12=-127;
  if (ipwm13 < -127) ipwm13=-127;
  if (ipwm14 < -127) ipwm14=-127;
  if (ipwm15 < -127) ipwm15=-127;
  if (ipwm16 < -127) ipwm16=-127;

  if (ipwm01 > 127) ipwm01=127;
  if (ipwm02 > 127) ipwm02=127;
  if (ipwm03 > 127) ipwm03=127;
  if (ipwm04 > 127) ipwm04=127;
  if (ipwm05 > 127) ipwm05=127;
  if (ipwm06 > 127) ipwm06=127;
  if (ipwm07 > 127) ipwm07=127;
  if (ipwm08 > 127) ipwm08=127;
  if (ipwm09 > 127) ipwm09=127;
  if (ipwm10 > 127) ipwm10=127;
  if (ipwm11 > 127) ipwm11=127;
  if (ipwm12 > 127) ipwm12=127;
  if (ipwm13 > 127) ipwm13=127;
  if (ipwm14 > 127) ipwm14=127;
  if (ipwm15 > 127) ipwm15=127;
  if (ipwm16 > 127) ipwm16=127;

	pwm01 = (unsigned char) ipwm01 +127;
	pwm02 = (unsigned char) ipwm02 +127;
	pwm03 = (unsigned char) ipwm03 +127;
	pwm04 = (unsigned char) ipwm04 +127;
	pwm05 = (unsigned char) ipwm05 +127;
	pwm06 = (unsigned char) ipwm06 +127;
	pwm07 = (unsigned char) ipwm07 +127;
	pwm08 = (unsigned char) ipwm08 +127;
	pwm09 = (unsigned char) ipwm09 +127;
	pwm10 = (unsigned char) ipwm10 +127;
	pwm11 = (unsigned char) ipwm11 +127;
	pwm12 = (unsigned char) ipwm12 +127;
	pwm13 = (unsigned char) ipwm13 +127;
	pwm14 = (unsigned char) ipwm14 +127;
	pwm15 = (unsigned char) ipwm15 +127;
	pwm16 = (unsigned char) ipwm16 +127;
}


/*******************************************************************************
* FUNCTION NAME: abs
* PURPOSE:       Return absolute value
*******************************************************************************/
unsigned int abs(signed int inb) 
{
  if(inb >= 0)
      return inb;
  else
      return -inb;
}


/*******************************************************************************
* FUNCTION NAME: Limit_Mix
* PURPOSE:       Limits the mixed value for one joystick drive.
* CALLED FROM:   Default_Routine, this file
* ARGUMENTS:     
*     Argument             Type    IO   Description
*     --------             ----    --   -----------
*     intermediate_value    int    I    
* RETURNS:       unsigned char
*******************************************************************************/
int Limit_Mix (int intermediate_value)
{
  static int limited_value;
  
  if (intermediate_value < -127)
  {
    limited_value = -127;
  }
  else if (intermediate_value > 127)
  {
    limited_value = 127;
  }
  else
  {
    limited_value = intermediate_value;
  }
  return (int) (limited_value);
}


/*******************************************************************************
* FUNCTION NAME: Smooth_Joystick
* PURPOSE:       This filter changes the joystick respinse curve and establishes
*                a bigger deadspot for the joysticks.
*                i.e., instead of neutral being exactly 0, it is -10 to 10.
*                so the motor is sent values of -127 to -10 or 10 to 127.
*                It also avoids the Victor deadspot.
* NOTES:         The Victor 884 range is: 0-37   = Full reverse
*                                        123-136 = Neutral
*                                        227-254 = Full Forward
*                In our terms:  0-9(4)   = Neutral
*                             (90)100-127 = Full  (!!I've noticed 110+ isn't full!!)
*******************************************************************************/
const rom signed char Joystick_Curve[128] = 
{
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   1,   1,   1,   1,   1,   2, 
  2,   2,   3,   3,   3,   4,   4,   4,   5,   5,   6,   6,   7,   7,   8,   8, 
  9,   9,  10,  10,  11,  12,  12,  13,  14,  14,  15,  16,  16,  17,  18,  19, 
 19,  20,  21,  22,  23,  24,  25,  25,  26,  27,  28,  29,  30,  31,  32,  33, 
 34,  35,  36,  37,  38,  39,  40,  42,  43,  44,  45,  46,  47,  49,  50,  51, 
 52,  54,  55,  56,  57,  59,  60,  61,  63,  64,  66,  67,  68,  70,  71,  73, 
 74,  76,  77,  79,  80,  82,  83,  85,  86,  88,  90,  91,  93,  94,  96,  98, 
100, 101, 103, 105, 106, 108, 110, 112, 114, 115, 117, 119, 121, 123, 125, 127
};

void Smooth_Joystick(int *p1)
{
  if(*p1 < 0)
     *p1 = -1 * Joystick_Curve[abs(*p1)];
  else
     *p1 = Joystick_Curve[*p1];
}


/*******************************************************************************
* FUNCTION NAME: Hold_Position
* PURPOSE:       Apply motor power to hold position if necessary.
*                This is also used to brake in User Driver mode, but will have
*                difficulty reaching a steady-state without a turn movement, 
*                because the minimum power for a turn is so high, e.g., PWM 70 vs.
*                PWM 20 and you'd need a counter-intuitive movement AWAY from the setpoint.
*                (When pushed by a person it reaches a max of ~70 pwm to counter)
* CALLED FROM:   User_Drive() & Brake()
*******************************************************************************/
#define KP 7/10  // Basic proportional adjustment (7/10 works)
#define KD 8  // Basic derivative adjustment (8 works)
#define KI 0  // Basic integral adjustment (0 works)
#define T  40 // This is executed at the slow loop rate of 40 Hz
#define ReverseStep 2  // Maximum allowed power increase during the first cycles
                       // Allows for gradual rather than abrupt braking
#define CUMLIMIT 20000  // Limit potential integral wind-up
#define INTEGRAL_WINDOW 10  //Integral window +/- to stop correcting

void Hold_Position(char init, int HoldLeft, int HoldRight)
{
  int pL, pR, dL, dR, iR, iL;
  static int LastActualL, LastActualR, ReverseLimit=127;
  static int CumErrorR, CumErrorL, Rerror, Lerror;

  if (init)
  { // Hold robot at these encoder values
    LastActualL = 0;
    LastActualR = 0;
    CumErrorR = 0;
    CumErrorL = 0;
    ReverseLimit = 20; // Use 127 if no ramp-up is desired
  }
  else
  {
    {
    Rerror = (Right_Encoder - HoldRight);
    Lerror = (Left_Encoder - HoldLeft);
    /* Proportional */
    /* Add correction proportional to the current error */
    /* Might want to match Left side response to Right */
    pR = Rerror * (int)KP;
    pL = Lerror  * (int)KP;

    /* Derivative */
    /* Sudden reaction to sudden changes */
    dR = (Right_Encoder - LastActualR) * (int)KD;
    dL = (Left_Encoder - LastActualL) * (int)KD;
    LastActualL = Left_Encoder;
    LastActualR = Right_Encoder;

    WHL_R1 = pR - dR; // could apply i to force robot completely back into position
    WHL_L1 = pL - dL;

    /* Keep the motors within permitted range */
  if ((WHL_R1 > -NULLJOYSTICK) && (WHL_R1 < NULLJOYSTICK))
    WHL_R1 = 0;  // Neutral

  if ((WHL_L1 > -NULLJOYSTICK) && (WHL_L1 < NULLJOYSTICK))
    WHL_L1 = 0;  // Neutral

    if (WHL_R1 < -127) WHL_R1 = -127;
    if (WHL_L1 < -127) WHL_L1 = -127;
    if (WHL_R1 > 127) WHL_R1 = 127;
    if (WHL_L1 > 127) WHL_L1 = 127;

    /* Apply ramp-up to full power rather than jumping right to full power */
    ReverseLimit += ReverseStep;
    if (ReverseLimit > 127) ReverseLimit = 127;
    if (WHL_R1 < -ReverseLimit) WHL_R1 = -ReverseLimit;
    if (WHL_L1 < -ReverseLimit) WHL_L1 = -ReverseLimit;
    if (WHL_R1 > ReverseLimit) WHL_R1 = ReverseLimit;
    if (WHL_L1 > ReverseLimit) WHL_L1 = ReverseLimit;

    WHL_R2 = WHL_R1;
    WHL_L2 = WHL_L1;
    }
  }
}




/*******************************************************************************
*	FUNCTION:		Initialize_Interrupts()
*	PURPOSE:		Initializes the interrupt hardware.
*	CALLED FROM:	user_routines.c/User_Initialization()
*******************************************************************************/
void Initialize_Interrupts(void)  
{
	// initialize external interrupt 1
//	OpenRB1INT(PORTB_CHANGE_INT_ON & 
//			   RISING_EDGE_INT &
//			   PORTB_PULLUPS_OFF);
	// initialize external interrupt 2
//	OpenRB2INT(PORTB_CHANGE_INT_ON & 
//			   RISING_EDGE_INT &
//			   PORTB_PULLUPS_OFF);
	// initialize external interrupts 3-6
//	OpenPORTB(PORTB_CHANGE_INT_ON & 
//			   PORTB_PULLUPS_OFF);
	// initialize external interrupt 1 (INT2 on user 18F8520)
	TRISBbits.TRISB2 = 1;		// make sure the RB2/INT2 pin is configured as an input [108]
								//
	INTCON3bits.INT2IP = 0;		// 0: interrupt 1 is low priority (leave at 0 for IFI controllers) [91]
								// 1: interrupt 1 is high priority
								//
	INTCON2bits.INTEDG2 = 1;	// 0: trigger on the falling-edge [90]
								// 1: trigger on the rising-edge
								//
	INTCON3bits.INT2IE = 1;		// 0: disable interrupt	1 [91]
								// 1: enable interrupt 1
	
	// initialize external interrupt 2 (INT3 on user 18F8520)
	TRISBbits.TRISB3 = 1;		// make sure the RB3/CCP2/INT3 pin is configured as an input [108]
								//
	INTCON2bits.INT3IP = 0;		// 0: interrupt 2 is low priority (leave at 0 for IFI controllers) [90]
								// 1: interrupt 2 is high priority
								//
	INTCON2bits.INTEDG3 = 1;	// 0: trigger on the falling-edge [90]
								// 1: trigger on the rising-edge
								//
	INTCON3bits.INT3IE = 1;		// 0: disable interrupt	2 [91]
								// 1: enable interrupt 2
    INTCONbits.GIEL = 1; // Enable low-priority interrupts
}
